==> haskell-containers-unicode-symbols-0.3.1.3-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-containers-unicode-symbols.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 containers-unicode-symbols
version:              0.3.1.3
visibility:           public
id:                   containers-unicode-symbols-0.3.1.3-LyMNtzcEc1H4F62brsFZGc
key:                  containers-unicode-symbols-0.3.1.3-LyMNtzcEc1H4F62brsFZGc
license:              BSD-3-Clause
copyright:            2009—2021 Roel van Dijk <roel@lambdeacube.nl>
maintainer:           Roel van Dijk <roel@lambdeacube.nl>
author:               Roel van Dijk <roel@lambdeacube.nl>
stability:            provisional
homepage:             http://haskell.org/haskellwiki/Unicode-symbols
synopsis:             Unicode alternatives for common functions and operators
description:
    This package defines new symbols for a number of functions and
    operators in the containers package.

    All symbols are documented with their actual definition and
    information regarding their Unicode code point. They should be
    completely interchangeable with their definitions.

abi:                  0d192e6f1cc30dbaaf16405bc90b5cb7
exposed:              True
exposed-modules:
    Data.IntMap.Lazy.Unicode Data.IntMap.Strict.Unicode
    Data.IntMap.Unicode Data.IntSet.Unicode Data.Map.Lazy.Unicode
    Data.Map.Strict.Unicode Data.Map.Unicode Data.Sequence.Unicode
    Data.Set.Unicode

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/containers-unicode-symbols-0.3.1.3

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/containers-unicode-symbols-0.3.1.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-containers-unicode-symbols
hs-libraries:         HScontainers-unicode-symbols-0.3.1.3-LyMNtzcEc1H4F62brsFZGc
depends:
    base-4.16.4.0 base-unicode-symbols-0.2.4.2-LxaiYZxX2IHCdJ6KOk7ePF
    containers-0.6.5.1

haddock-interfaces:
    /usr/share/doc/haskell-containers-unicode-symbols/html/containers-unicode-symbols.haddock

haddock-html:         /usr/share/doc/haskell-containers-unicode-symbols/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-containers-unicode-symbols-0.3.1.3-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-containers-unicode-symbols.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 containers-unicode-symbols
version:              0.3.1.3
visibility:           public
id:                   containers-unicode-symbols-0.3.1.3-IkcxoAAcOusKLaQNHbp7wA
key:                  containers-unicode-symbols-0.3.1.3-IkcxoAAcOusKLaQNHbp7wA
license:              BSD-3-Clause
copyright:            2009—2021 Roel van Dijk <roel@lambdeacube.nl>
maintainer:           Roel van Dijk <roel@lambdeacube.nl>
author:               Roel van Dijk <roel@lambdeacube.nl>
stability:            provisional
homepage:             http://haskell.org/haskellwiki/Unicode-symbols
synopsis:             Unicode alternatives for common functions and operators
description:
    This package defines new symbols for a number of functions and
    operators in the containers package.

    All symbols are documented with their actual definition and
    information regarding their Unicode code point. They should be
    completely interchangeable with their definitions.

abi:                  d48e70ec7d56c76886dcda71e85c162d
exposed:              True
exposed-modules:
    Data.IntMap.Lazy.Unicode Data.IntMap.Strict.Unicode
    Data.IntMap.Unicode Data.IntSet.Unicode Data.Map.Lazy.Unicode
    Data.Map.Strict.Unicode Data.Map.Unicode Data.Sequence.Unicode
    Data.Set.Unicode

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/containers-unicode-symbols-0.3.1.3

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/containers-unicode-symbols-0.3.1.3

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/containers-unicode-symbols-0.3.1.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-containers-unicode-symbols
hs-libraries:         HScontainers-unicode-symbols-0.3.1.3-IkcxoAAcOusKLaQNHbp7wA
depends:
    base-4.17.2.1 base-unicode-symbols-0.2.4.2-DGP2ohBQv5PB4jg5C9PUqH
    containers-0.6.7

haddock-interfaces:
    /usr/share/doc/haskell-containers-unicode-symbols/html/containers-unicode-symbols.haddock

haddock-html:         /usr/share/doc/haskell-containers-unicode-symbols/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
